==> haskell-vty-5.28.2-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vty
version:              5.28.2
visibility:           public
id:                   vty-5.28.2-GLLyHKnRxzP4JoqEoqAC5F
key:                  vty-5.28.2-GLLyHKnRxzP4JoqEoqAC5F
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.

    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.

    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  747c63ce54fe0d4d309d07a18e35b02e
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Attributes.Color Graphics.Vty.Config
    Graphics.Vty.Debug Graphics.Vty.DisplayAttributes
    Graphics.Vty.Error Graphics.Vty.Image Graphics.Vty.Image.Internal
    Graphics.Vty.Inline Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

hidden-modules:
    Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
    Graphics.Vty.Input.Terminfo.ANSIVT

import-dirs:          /usr/lib/ghc-8.10.1/site-local/vty-5.28.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/vty-5.28.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/vty-5.28.2
hs-libraries:         HSvty-5.28.2-GLLyHKnRxzP4JoqEoqAC5F
depends:
    ansi-terminal-0.10.3-20y7uVSxZd99OPB0BUeuF9 base-4.14.0.0
    binary-0.8.8.0 blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    hashable-1.3.0.0-FGLT5ncsVvTFKpMkBcbN1N
    microlens-0.4.11.2-DI50OTT3llTDsW32epWmE8
    microlens-mtl-0.2.0.1-30gu8BHYazP9sT79KAgW65
    microlens-th-0.4.3.5-9n2o51UXxOZ7SrtcDAHpl9 mtl-2.2.2
    parallel-3.2.2.0-67hDU2xqF8SLdjRsxBpKaE parsec-3.1.14.0 stm-2.5.0.0
    terminfo-0.4.1.4 text-1.2.3.2 transformers-0.5.6.2 unix-2.7.2.2
    utf8-string-1.0.1.1-L5P9SR8YxIu1NqwMrJwV7a
    vector-0.12.1.2-2820kU4E8Rq2FpOG9Xf2aE

haddock-interfaces:   /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-5.28.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vty
version:              5.28.2
visibility:           public
id:                   vty-5.28.2-5lMcNXdp5hLELJHvOpACf2
key:                  vty-5.28.2-5lMcNXdp5hLELJHvOpACf2
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.

    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.

    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  5618328411394d01b14a458174de259e
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Attributes.Color Graphics.Vty.Config
    Graphics.Vty.Debug Graphics.Vty.DisplayAttributes
    Graphics.Vty.Error Graphics.Vty.Image Graphics.Vty.Image.Internal
    Graphics.Vty.Inline Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

hidden-modules:
    Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
    Graphics.Vty.Input.Terminfo.ANSIVT

import-dirs:          /usr/lib/ghc-8.10.1/site-local/vty-5.28.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/vty-5.28.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/vty-5.28.2
hs-libraries:         HSvty-5.28.2-5lMcNXdp5hLELJHvOpACf2
depends:
    ansi-terminal-0.10.3-5vk5RxWeM0oExYuXrKVvGT base-4.14.0.0
    binary-0.8.8.0 blaze-builder-0.4.1.0-2R9yQhqQRKlArR2rpVisZG
    bytestring-0.10.10.0 containers-0.6.2.1 deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    hashable-1.3.0.0-EAzOv9XkxZx208nV7jdDUC
    microlens-0.4.11.2-DI50OTT3llTDsW32epWmE8
    microlens-mtl-0.2.0.1-30gu8BHYazP9sT79KAgW65
    microlens-th-0.4.3.5-9n2o51UXxOZ7SrtcDAHpl9 mtl-2.2.2
    parallel-3.2.2.0-67hDU2xqF8SLdjRsxBpKaE parsec-3.1.14.0 stm-2.5.0.0
    terminfo-0.4.1.4 text-1.2.3.2 transformers-0.5.6.2 unix-2.7.2.2
    utf8-string-1.0.1.1-L5P9SR8YxIu1NqwMrJwV7a
    vector-0.12.1.2-2820kU4E8Rq2FpOG9Xf2aE

haddock-interfaces:   /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
